@@ -497,7 +497,7 @@ object or the name of the stage.
 		my $self = shift;
 		my $stages = $self->_stages;
 		return
-		    map  { $self->croak( "Unknown stage name ($_) passed to add_deps" ) 
+		    map  { $self->_croak( "Unknown stage name ($_) passed to add_deps" ) 
 			           unless exists $stages->{$_};
 				   $_
 				 }
