@@ -95,6 +95,18 @@ has 'log_path' => (
 	},
 );
 
+has 'log_no_stdout' => (
+	is      => 'ro',
+	isa     => 'Bool',
+	default => '0',
+);
+
+has 'log_no_file' => (
+	is      => 'ro',
+	isa     => 'Bool',
+	default => '0',
+);
+
 subtype 'LogLevel',
     as 'Num';
 
@@ -208,19 +220,6 @@ sub _default_logger {
 
 	$log->level( $self->log_level );
 
-	# Appenders - they specify where logging events should be printed/sent
-	my $file_appender = Log::Log4perl::Appender->new(
-		"Log::Log4perl::Appender::File",
-		filename => $self->log_path,
-		mode     => 'append',
-	);
-
-    my $stdout_appender = Log::Log4perl::Appender->new(
-        'Log::Log4perl::Appender::Screen',
-        stderr => 0,
-        utf8  => 1,
-    );
-
     # Layouts - output formats for appenders. See here for specification:
     # (http://search.cpan.org/~mschilli/Log-Log4perl-1.40/lib/Log/Log4perl/Layout/PatternLayout.pm)
 	my %layout = (
@@ -229,13 +228,33 @@ sub _default_logger {
 	);
 	$_ = Log::Log4perl::Layout::PatternLayout->new($_) for values %layout;
 
-    $file_appender->layout($layout{verbose});
-    $stdout_appender->layout($layout{simple});
+	if ($self->log_no_file) {
+		$log->debug("No file logger initialized");
+	}
+	else {
+		my $file_appender = Log::Log4perl::Appender->new(
+			"Log::Log4perl::Appender::File",
+			filename => $self->log_path,
+			mode     => 'append',
+		);
+		$file_appender->layout($layout{verbose});
+		$log->add_appender($file_appender);
+		$log->debug("File logger initialized");
+	}
 
-    $log->add_appender($file_appender);
-    $log->add_appender($stdout_appender);
-
-    $log->debug("Logger initialized");
+	if ($self->log_no_stdout) {
+		$log->debug("No stdout logger initialized");
+	}
+	else {
+		my $stdout_appender = Log::Log4perl::Appender->new(
+			'Log::Log4perl::Appender::Screen',
+			stderr => 0,
+			utf8  => 1,
+		);
+		$stdout_appender->layout($layout{simple});
+		$log->add_appender($stdout_appender);
+		$log->debug("Stdout logger initialized");
+	}
 
 	$self->_init_stage(2);
     return $log;
